# Kandy CPaaS Python SDK

## Install

Install the package with:

```bash
pip install cpaassdk
```

## Reference

The information about tutorials and documents can be found in the links below

* `Documents`: [API Docs](https://kandy-io.github.io/kandy-cpaas-python-sdk/docs)

* `Tutorials`:  [User Guide](https://Kandy-IO.github.io/kandy-cpaas-python-sdk/tutorials/?KANDY=Kandy&KANDYFQDN=oauth-cpaas.att.com#/GetStarted)

## Compatibility
- Python 3.0 or higher
